@@ -24,12 +24,11 @@ import org.videolan.libvlc.LibVlcUtil;
 import org.videolan.vlc.R;
 import org.videolan.vlc.audio.AudioServiceController;
 import org.videolan.vlc.interfaces.IRefreshable;
+import org.videolan.vlc.widget.SwipeRefreshLayout;
 
 import android.annotation.TargetApi;
 import android.os.Build;
 import android.os.Bundle;
-import android.support.v4.widget.SwipeRefreshLayout;
-import android.support.v7.app.ActionBarActivity;
 import android.view.ContextMenu;
 import android.view.ContextMenu.ContextMenuInfo;
 import android.view.LayoutInflater;
@@ -181,4 +180,6 @@ public class HistoryFragment extends BrowserFragment implements IRefreshable, Sw
     protected String getTitle() {
         return getString(R.string.history);
     }
+
+    public void clear(){}
 }
