@@ -39,7 +39,6 @@ import android.widget.Button;
 import android.widget.SeekBar;
 import android.widget.TextView;
 
-import org.videolan.libvlc.LibVLC;
 import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
@@ -68,6 +67,8 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
     public static final int DIALOG_LISTENER = 3;
     public static final int RESET_RETRY = 4;
 
+    private TextView mAudioMode;
+
     private TextView mSpeedTv;
     private SeekBar mSeek;
     private Button mReset;
@@ -107,6 +108,10 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                              Bundle savedInstanceState) {
         View root = inflater.inflate(R.layout.fragment_advanced_options, container, false);
 
+        mAudioMode = (TextView) root.findViewById(R.id.playback_switch_audio);
+        mAudioMode.setOnClickListener(this);
+        mAudioMode.setOnFocusChangeListener(mFocusListener);
+
         mSeek = (SeekBar) root.findViewById(R.id.playback_speed_seek);
         mSpeedTv = (TextView) root.findViewById(R.id.playback_speed_value);
         mReset = (Button) root.findViewById(R.id.playback_speed_reset);
@@ -311,6 +316,9 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 setSleep(v.getContext(), null);
                 mHandler.sendEmptyMessage(TOGGLE_CANCEL);
                 break;
+            case R.id.playback_switch_audio:
+                ((VideoPlayerActivity)getActivity()).switchToAudioMode();
+                break;
         }
     }
 }
